@@ -3,23 +3,41 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use base qw{ Module::Build };
+use Module::Build;
+our @ISA = qw{ Module::Build };
 
 use Carp;
-
+use My::Module::Recommend;
 
 sub ACTION_authortest {
-    my ( $self, @args ) = @_;
+##  my ( $self, @args ) = @_;
+    my ( $self ) = @_;		# Arguments unused
 
     local $ENV{AUTHOR_TESTING} = 1;
 
-    $self->depends_on( 'build' );
-    $self->test_files( qw{ t xt/author } );
+    my @depends_on = ( qw{ build } );
+    -e 'META.json' or push @depends_on, 'distmeta';
+    $self->depends_on( @depends_on );
+
+    $self->test_files( qw{ t xt/author },
+	My::Module::Recommend->make_optional_modules_tests() );
+
     $self->depends_on( 'test' );
 
     return;
 }
 
+sub harness_switches {
+    my ( $self ) = @_;
+    my @res = $self->SUPER::harness_switches();
+    foreach ( @res ) {
+	'-MDevel::Cover' eq $_
+	    or next;
+	$_ .= '=-db,cover_db,-ignore,inc/mock/';
+    }
+    return @res;
+}
+
 1;
 
 __END__
@@ -77,7 +95,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2011-2016 by Thomas R. Wyant, III
+Copyright (C) 2009, 2011-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
